@@ -48,6 +48,12 @@ class EasyDict(dict):
     >>> d.bar.prop = 'newer'
     >>> d.bar.prop
     'newer'
+    >>> d.lst = [1, 2, 3]
+    >>> d.lst
+    [1, 2, 3]
+    >>> d.tpl = (1, 2, 3)
+    >>> d.tpl
+    (1, 2, 3)
 
 
     Values extraction
@@ -117,6 +123,12 @@ class EasyDict(dict):
     Traceback (most recent call last):
     ...
     AttributeError: 'EasyDict' object has no attribute 'a'
+    >>> d.pop('a', 8)
+    8
+    >>> d.pop('b', 100)
+    4
+    >>> d
+    {'c': 3.0}
     """
     def __init__(self, d=None, **kwargs):
         if d is None:
@@ -129,13 +141,13 @@ class EasyDict(dict):
             setattr(self, k, v)
         # Class attributes
         for k in self.__class__.__dict__.keys():
-            if not (k.startswith('__') and k.endswith('__')) and not k in ('update', 'pop'):
+            if not (k.startswith('__') and k.endswith('__')) and k not in ('update', 'pop'):
                 setattr(self, k, getattr(self, k))
 
     def __setattr__(self, name, value):
         if isinstance(value, (list, tuple)):
-            value = [self.__class__(x)
-                     if isinstance(x, dict) else x for x in value]
+            value = type(value)(self.__class__(x)
+                     if isinstance(x, dict) else x for x in value)
         elif isinstance(value, dict) and not isinstance(value, EasyDict):
             value = EasyDict(value)
         super(EasyDict, self).__setattr__(name, value)
@@ -149,9 +161,10 @@ class EasyDict(dict):
         for k in d:
             setattr(self, k, d[k])
 
-    def pop(self, k, d=None):
-        delattr(self, k)
-        return super(EasyDict, self).pop(k, d)
+    def pop(self, k, *args):
+        if hasattr(self, k):
+            delattr(self, k)
+        return super(EasyDict, self).pop(k, *args)
 
 
 if __name__ == "__main__":
